@@ -500,7 +500,7 @@ makehelp(const char *file)
 		}
 	}
 	if (show_position)
-		fprintf(op, "[+line file]");
+		fprintf(op, "%s%s value='+<line number> <file>' %s", quote_space, position_begin, position_end);
 	fputs(" */", op);
 	if (!Iflag)
 		fputs_nl(verbatim_end, op);
@@ -521,10 +521,10 @@ makehelp(const char *file)
 	}
 	if (show_position) {
 		fputs(define_term_begin, op);
-		fputs("[+line file]", op);
+		fprintf(op, "%s%s value='+<line number> <file>' %s", quote_space, position_begin, position_end);
 		fputs(define_term_end, op);
 		fputs(define_desc_begin, op);
-		fputs("Current position (line number and file name).", op);
+		fputs("The current position (line number and file name).", op);
 		fputs_nl(define_desc_end, op);
 	}
 	fputs_nl(define_list_end, op);
@@ -698,32 +698,13 @@ makesearchindex(const char *file)
  * makehtaccess: make ".htaccess" skeleton file.
  */
 static void
-makehtaccess(const char *cgidir, const char *file, int perm)
+makehtaccess(const char *file, int perm)
 {
-	FILE *op;
+	char src[MAXPATHLEN];
 	const char *dst = makepath(distpath, file, NULL);
 
-	op = fopen(dst, "w");
-	if (!op)
-		die("cannot make .htaccess skeleton file.");
-	fputs_nl("#", op);
-	fputs_nl("# Skeleton file for .htaccess -- This file was generated by htags(1).", op);
-	fputs_nl("#", op);
-	fputs_nl("# To make this file effective, undermentioned description is necessary", op);
-	fputs_nl("# in your system's configuration file.", op);
-	fputs_nl("#", op);
-	fputs_nl("# [/usr/local/apache/conf/http.conf]", op);
-	fputs_nl("# +-------------------------------------", op);
-	fputs_nl("# |...", op);
-	fputs_nl("# |AllowOverride Options FileInfo", op);
-	fputs_nl("#", op);
-	fputs_nl("# Htags was invoked with the -f, or -D option.", op);
-	fprintf(op, "# You should start http server so that %s/*.cgi is executed\n", cgidir);
-	fputs_nl("# as a CGI script.", op);
-	fputs_nl("#", op);
-	fputs_nl("Options +ExecCGI", op);
-	fputs_nl("AddHandler cgi-script .cgi", op);
-	fclose(op);
+	snprintf(src, sizeof(src), "%s/gtags/dot_htaccess", datadir);
+	copyfile(src, dst);
 	if (chmod(dst, perm) < 0)
 		die("cannot chmod .htaccess skeleton.");
 }
@@ -1531,7 +1512,7 @@ main(int argc, char **argv)
 			makeprogram(cgidir, "global.cgi", 0755);
 		if (auto_completion)
 			makeprogram(cgidir, "completion.cgi", 0755);
-		makehtaccess(cgidir, ".htaccess", 0644);
+		makehtaccess(".htaccess", 0644);
 	} else {
 		message("[%s] (1) making CGI program ...(skipped)", now());
 	}
@@ -1678,6 +1659,7 @@ main(int argc, char **argv)
 		message("\n[Information]\n");
 		message(" o Htags was invoked with the -f, -c, -D or --auto-completion option. You should");
 		message("   start http server so that cgi-bin/*.cgi is executed as a CGI script.");
+		message("   Use of htags-server(1) is recommended.");
  		message("\n If you are using Apache, 'HTML/.htaccess' might be helpful for you.\n");
 		message(" Good luck!\n");
 	}
