@@ -299,17 +299,18 @@ C_family(const struct parser_param *param, int type)
 		case C_UNION:
 			while ((c = nexttoken(interested, c_reserved_word)) == C___ATTRIBUTE__)
 				process_attribute(param);
+			while (c == '\n')
+				c = nexttoken(interested, c_reserved_word);
 			if (c == SYMBOL) {
 				if (peekc(0) == '{') /* } */ {
 					PUT(PARSER_DEF, token, lineno, sp);
-					do {
-						c = nexttoken(interested, c_reserved_word);
-					} while (c == '\n');
 				} else {
 					PUT(PARSER_REF_SYM, token, lineno, sp);
-					c = nexttoken(interested, c_reserved_word);
 				}
+				c = nexttoken(interested, c_reserved_word);
 			}
+			while (c == '\n')
+				c = nexttoken(interested, c_reserved_word);
 			if (c == '{' /* } */ && cc == C_ENUM) {
 				enumerator_list(param);
 			} else {
@@ -358,18 +359,19 @@ C_family(const struct parser_param *param, int type)
 
 					while ((c = nexttoken(interest_enum, c_reserved_word)) == C___ATTRIBUTE__)
 						process_attribute(param);
+					while (c == '\n')
+						c = nexttoken(interest_enum, c_reserved_word);
 					/* read tag name if exist */
 					if (c == SYMBOL) {
 						if (peekc(0) == '{') /* } */ {
 							PUT(PARSER_DEF, token, lineno, sp);
-							do {
-								c = nexttoken(interest_enum, c_reserved_word);
-							} while (c == '\n');
 						} else {
 							PUT(PARSER_REF_SYM, token, lineno, sp);
-							c = nexttoken(interest_enum, c_reserved_word);
 						}
+						c = nexttoken(interest_enum, c_reserved_word);
 					}
+					while (c == '\n')
+						c = nexttoken(interest_enum, c_reserved_word);
 					if (c_ == C_ENUM) {
 						if (c == '{') /* } */
 							c = enumerator_list(param);
