@@ -44,38 +44,33 @@ typedef void* HANDLE;
 #define VERSIONKEY	" __.VERSION"
 
 typedef	struct {
-	/**
-	 * @name (1) COMMON PART
+	/*
+	 * (1) COMMON PART
 	 */
-	/** @{ */
 	int mode;			/**< 0:read, 1:create, 2:modify */
-	int openflags;			/**< flags of @NAME{xxxx_open()} */
-	int ioflags;			/**< flags of @NAME{xxxx_first()} */
+	int openflags;			/**< flags of xxxx_open() */
+	int ioflags;			/**< flags of xxxx_first() */
 	char *lastdat;			/**< the data of last located record */
 	int lastsize;			/**< the size of the lastdat */
 	char *lastkey;			/**< the key of last located record */
 	int lastkeysize;		/**< the size of the key */
 	regex_t	*preg;			/**< compiled regular expression */
 	int unread;			/**< leave record to read again */
-	const char *put_errmsg;		/**< error message for @NAME{put_xxx()} */
-	/** @} */
+	const char *put_errmsg;		/**< error message for put_xxx() */
 
-	/**
-	 * @name (2) DB185 PART
+	/*
+	 * (2) DB185 PART
 	 */
-	/** @{ */
 	DB *db;				/**< descripter of DB */
 	char dbname[MAXPATHLEN];	/**< dbname */
 	char key[MAXKEYLEN];		/**< key */
 	int keylen;			/**< key length */
 	char prev[MAXKEYLEN];		/**< previous key value */
 	int perm;			/**< file permission */
-	/** @} */
 
-	/**
-	 * @name (3) sorted write
+	/*
+	 * (3) sorted write
 	 */
-	/** @{ */
 	FILE *sortout;			/**< write to sort command */
 	FILE *sortin;			/**< read from sort command */
 #if defined(_WIN32) && !defined(__CYGWIN__)
@@ -83,10 +78,9 @@ typedef	struct {
 #else
 	int pid;			/**< sort process id */
 #endif
-	/** @} */
 #ifdef USE_SQLITE3
-	/**
-	 * @name (4) sqlite3 part
+	/*
+	 * (4) sqlite3 part
 	 */
 	sqlite3 *db3;
 	STRBUF *sb;
@@ -105,22 +99,19 @@ typedef	struct {
 #endif
 } DBOP;
 
-/**
- * @name openflags
+/*
+ * openflags
  */
-/** @{ */
 		/** allow duplicate records	*/
 #define	DBOP_DUP	1
 #ifdef USE_SQLITE3
-		/* use sqlite3 database		*/
+		/** use sqlite3 database		*/
 #define DBOP_SQLITE3	2
 #endif
-/** @} */
 
-/**
- * @name ioflags
+/*
+ * ioflags
  */
-/** @{ */
 			/** read key part */
 #define DBOP_KEY		1
 			/** prefixed read */
@@ -129,7 +120,6 @@ typedef	struct {
 #define DBOP_RAW		4
 			/** sorted write */
 #define DBOP_SORTED_WRITE	8
-/** @} */
 
 DBOP *dbop_open(const char *, int, int, int);
 const char *dbop_get(DBOP *, const char *);
