@@ -1,6 +1,7 @@
 /*
  * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2005, 2006, 2008,
- *	2009, 2011, 2012, 2014, 2015 Tama Communications Corporation
+ *	2009, 2011, 2012, 2014, 2015, 2016
+ * Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -78,7 +79,10 @@
 #define STRNCMP strncmp
 #define ROOT 0
 #endif
-
+#ifndef PATH_MAX
+#error Since this platform does not have PATH_MAX, you should define it using an appropriate value for the platform.
+/* #define PATH_MAX     1024 */
+#endif
 /*
  * usage of find_xxx()
  *
